summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMitch Garnaat <mitch@cloudright.com>2010-09-03 11:55:23 -0400
committerMitch Garnaat <mitch@cloudright.com>2010-09-03 11:55:23 -0400
commit13e568f6f55d495c6ba3df445cfbf2a1e21182f3 (patch)
tree01e7c81fa3ef68e1c7627732f64d750fd4a7801f
parent02c8c0ac2e116c4577433149575acc950d1c04b8 (diff)
downloadboto-13e568f6f55d495c6ba3df445cfbf2a1e21182f3.tar.gz
Added delete_group method.
-rw-r--r--boto/iam/__init__.py14
1 files changed, 13 insertions, 1 deletions
diff --git a/boto/iam/__init__.py b/boto/iam/__init__.py
index 12c3a080..d4bfff20 100644
--- a/boto/iam/__init__.py
+++ b/boto/iam/__init__.py
@@ -132,6 +132,18 @@ class IAMConnection(AWSQueryConnection):
'Path' : path}
return self.get_response('CreateGroup', params)
+ def delete_group(self, group_name):
+ """
+ Delete a group. The group must not contain any Users or
+ have any attached policies
+
+ :type group_name: string
+ :param group_name: The name of the group to delete.
+
+ """
+ params = {'GroupName' : group_name}
+ return self.get_response('DeleteGroup', params)
+
def update_group(self, group_name, new_group_name=None, new_path=None):
"""
Update a group by adding or removing a user to/from it.
@@ -310,7 +322,7 @@ class IAMConnection(AWSQueryConnection):
def delete_user(self, user_name):
"""
Create a user including the user's path, GUID and ARN.
If the user_name is not specified, the user_name is determined
implicitly based on the AWS Access Key ID used to sign the request.
@@ -310,7 +322,7 @@ class IAMConnection(AWSQueryConnection):
def delete_user(self, user_name):
"""
- Create a user including the user's path, GUID and ARN.
+ Delete a user including the user's path, GUID and ARN.
If the user_name is not specified, the user_name is determined
implicitly based on the AWS Access Key ID used to sign the request.